import random
import os
import platform
def ranNum(low, high):
    return random.randint(low, high)
def ranFloat(low, high):
    return random.uniform(low, high)
def cap(num, decimalPlaces):
    return format(num, f".{decimalPlaces}f")
def package(module):
    os.system(f"pip install {module}")
def runCmd(cmd):
    os.system(cmd)
def osName():
    return platform.system()
def py2dmg(filename, iconFileName = ''):
    if iconFileName == '':
        setup = open("../setup.py", "w")
        setup.write("from setuptools import setup\n")
        setup.write(f"APP = ['{filename}']\n")
        setup.write("OPTIONS = {\n'argv_emulation': True\n}\n")
        setup.write("setup(\napp = APP, \noptions = {\n'py2app': OPTIONS\n}, \nsetup_requires = ['py2app'])\n")
        setup.close()
        os.system("python setup.py py2app")
    else:
        """"""
        setup = open("../setup.py", "w")
        setup.write("from setuptools import setup\n")
        setup.write(f"APP = ['{filename}']\n")
        setup.write("OPTIONS = {\n'iconfile':'{%s}',\n 'plist': {'CFBundleShortVersionString':'0.1.0'}\n}\n"%(iconFileName))
        setup.write("setup(\napp = APP, \noptions = {\n'py2app': OPTIONS\n}, \nsetup_requires = ['py2app'])\n")
        setup.close()
        os.system("python setup.py py2app")

def py2exe(filename, console=False, iconFileName = ''):
    if console == False:
        os.system(f'pyinstaller --onefile --noconsole "{filename}"')
    elif console == False and iconFileName != '':
        os.system(f'pyinstaller --onefile --noconsole --icon = "{iconFileName}" "{filename}"')
    elif console == True:
        os.system(f'pyinstaller --onefile "{filename}"')
    elif console == True and iconFileName != '':
        os.system(f'pyinstaller --onefile --icon = "{iconFileName}" "{filename}"')

def write(filename, text):
    file = open(filename, "w")
    file.write(text)
    file.close()


def read(filename, mode = 't'):
    if mode == 't':
        with open(filename, "r") as file:
            return file.readlines()
        file.close()
    else:
        with open(filename, "rb") as file:
            return file.readlines()
        file.close()

def append(filename, text):
    with open(filename, "a+") as f:
        f.write(text)
def create(filename):
    open(filename, "x")



from PyEasier.PyEasier import ranNum
from PyEasier.PyEasier import ranFloat
from PyEasier.PyEasier import append
from PyEasier.PyEasier import write
from PyEasier.PyEasier import osName
from PyEasier.PyEasier import cap
from PyEasier.PyEasier import package
from PyEasier.PyEasier import runCmd
from PyEasier.PyEasier import py2dmg
from PyEasier.PyEasier import py2exe
from PyEasier.PyEasier import read
from PyEasier.PyEasier import create


from setuptools import setup, find_packages

VERSION = '0.0.4.1'
DESCRIPTION = 'Making your python experience better'

# Setting up
setup(
    name="PyEasier",
    version=VERSION,
    author="Yellow Yams(Vedic Mukherjee)",
    author_email="<yellowyams5@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=['py2app', 'pyinstaller'],
    keywords=['python', 'PyEasier', 'quick code', 'fast development', 'easy to use', 'build'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)

